#
# spec file for package catfish
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
%define series 4.18
Name:           catfish
Version:        4.18.0
Release:        2.6
Summary:        Versatile File Searching Tool
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
URL:            https://docs.xfce.org/apps/catfish/start
Source:         https://archive.xfce.org/src/apps/%{name}/%{series}/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE: Force-disable Zeitgeist
Patch0:         0001-Force-disable-Zeitgeist-support.patch
BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
%if 0%{?suse_version} >= 01550 || 0%{?sle_version} >= 150200 && 0%{?is_opensuse}
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  update-desktop-files
# Needed for typelib() - Requires.
BuildRequires:  gobject-introspection
# Checking module dependencies...
BuildRequires:  gtk3-devel >= 3.22
BuildRequires:  python3-distutils-extra
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-Gdk
BuildRequires:  python3-pexpect
BuildRequires:  python3-xml
# ...OK
Requires:       findutils-locate
Requires:       gdk-pixbuf-loader-rsvg
Requires:       gsettings-backend-dconf
Requires:       python3-cairo
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-gobject-cairo
Requires:       python3-pexpect
Requires:       python3-xml
Requires:       sudo
Recommends:     %{name}-lang
BuildArch:      noarch

%description
Catfish is a GTK+ search utility written in python. Its search is powered by
/usr/bin/find and /usr/bin/locate, with search suggestions provided by
zeitgeist.

%lang_package

%prep
%autosetup -p1

%build
python3 ./setup.py build -g

%install
python3 ./setup.py install -O1 \
    --prefix="%{_prefix}" \
    --root="%{buildroot}"
rm -rf %{buildroot}%{_datadir}/doc/%{name}
# Fix: non-executable-script
pushd %{buildroot}
for _file in $(grep -rl '^\#\!\/'); do
  find -name ${_file##*/} -type f -not -perm /111 -exec sed '/^\#\!\//d' -i {} \+
  find -name ${_file##*/} -type f -perm /111 -exec sed '/^\#\!\/.\+py/s/env\ \+//' -i {} \+
done
%py3_compile -O .%{python3_sitelib}
popd
sed -i "s/\(Exec=\).*/\1%{name}/" %{buildroot}%{_datadir}/applications/org.xfce.Catfish.desktop

%suse_update_desktop_file -r org.xfce.Catfish GNOME Utility Filesystem

%fdupes %{buildroot}%{python3_sitelib}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml

%find_lang %{name}

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/org.xfce.Catfish.desktop
%{_datadir}/icons/hicolor/*/apps/org.xfce.catfish.*
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}_lib
%{python3_sitelib}/%{name}-%{version}-py%{py3_ver}.egg-info
%{_mandir}/man?/%{name}.?%{ext_man}

%files lang -f %{name}.lang

%changelog
* Tue Feb  6 2024 Manfred Hollstein <manfred.h@gmx.net>
- As long as a new Python version does not ship a broken
  python3-distutils, like python311 did in its early days, there is
  no need to deal with or skip a specific python version at all.
  Disable all %%%%{python_module ...} and skip_python... stuff again.
* Tue Feb  6 2024 Manfred Hollstein <manfred.h@gmx.net>
- Don't use %%%%{python_module ...} as we only build for the default
  Python interpreter. python312 still needs to be skipped due to
  python3-distutils!
* Sat Feb  3 2024 Manfred Hollstein <manfred.h@gmx.net>
- Skip python312 for now until all required Python modules have been
  built.
* Wed Nov 15 2023 Manfred Hollstein <manfred.h@gmx.net>
- Use %%%%{python_module ...} to specify required Python modules to
  build this package.
* Sun Aug  6 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.0
  * Filters: Add Archives, Other, update Apps
  * Use Gio to open files, fix "no default app" issue
  * Add symlink emblem to thumbnails in thumbnail mode
  * config: Prefer plocate over mlocate if available
  * window: Avoid IndexError on right click when selection is empty
  * Create shared filetype lists for searching and filtering
  * Ensure site-packages directory is prepended to sys.path
  * Fix double border between sidebar and results area
  * window: Fix and refactor new_column()
  * window: Fix markup warnings in thumbnail view
  * Fix GtkBuilder warnings
  * Revert "Suppress the various GTK warnings GtkBuilder outputs"
  * Fix crash and translations when install prefix != /usr
  * Update `.gitignore`
  * Remove generated file po/catfish.pot
  * Performance improvements (fix #79)
  * Translation Updates
- Refresh 0001-Force-disable-Zeitgeist-support.patch
- Remove _service file
* Sun Jul 17 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.4
  * Add "Open with" right click item and dialog
    (gxo#apps/catfish#12)
  * Add a command-line option for setting default sort method
  * Add Ctrl+A accelerator for the treeview (gxo#apps/catfish#64)
  * Add option to show file size in binary or decimal
  * Cosmetic changes for search entry and delete dialog
  * Fix Ctrl+H not always toggling hidden files
  * Fix DE detection when launched from Electron apps
  * Fix exo file manager lookup for non-existent keys
    (gxo#apps/catfish#64)
  * Fix file manager lookup outside of Xfce
  * Fix GNOME DE detection in Ubuntu
  * Improve application menu appearance
  * Improve default width for the sidebar
  * Prepend the project root directory to sys.path
  * Support running without Xfconf (no preference saving)
  * Switch to using the super() method
  * Use correct executable for elementary Files
  * Translation Updates
* Sun Sep 26 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.3
  * Update "Searching..." Cursor
  * Sidebar background color bugfix
  * Fixes for syntax, fulltext zip search, special files
    (gxo#apps/catfish#62)
  * Adds symbolic link icons, better icon updating
    (gxo#apps/catfish#46)
  * Translation Updates
* Tue Aug 24 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed package sources that disappeared
* Sat Jul 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.2
  * Use standard icon name application-x-executable-symbolic
    instead of applications-other-symbolic
  * Fix install with rpm/pkgbuild/pip
    (gxo#apps/catfish#58, gxo#apps/catfish#59)
  * Added keyboard hotkeys for search entry, new open dialog
  * Fix Thunar "Show in FM" bug, better FM support
    (gxo#apps/catfish#43)
  * Stops freezes with special files when zip search enabled
  * Better and safer refreshing of selected results
    (gxo#apps/catfish#48)
  * Enable sidebar by default (gxo#apps/catfish#45)
  * Enable installation using pip (local source)
    (gxo#apps/catfish!20)
  * Add support for searching compressed files (gxo#apps/catfish#29)
  * Add persistent settings for searching file contents
    (gxo#apps/catfish#10)
  * Add persistent settings for thumbnail view (gxo#apps/catfish#14)
  * Add message and troff mimetypes to fulltext search
    (gxo#apps/catfish!22)
  * Add PDF support to fulltext search (gxo#apps/catfish#37)
  * Fix loading in Wayland (gxo#apps/catfish#50)
  * Stop current search when new one starts (gxo#apps/catfish!28)
  * Use local MIME database info (gxo#apps/catfish!21)
  * Translation Updates
* Fri Jan  8 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.0
  * Fulltext now searches files with UTF-7, UTF-8, UTF-16 BE/LE,
    and UTF-32 BE/LE encodings
  * Replace Gtk/Gdk/GLib deprecated code (gxo#apps/catfish#6)
  * Use "match all" method for fulltext search (gxo#apps/catfish#30)
  * Translation Updates
* Wed Nov 18 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- add 0001-Force-disable-Zeitgeist-support.patch
  * avoid automatically generated typelib(Zeitgeist) dependency
    we can not provide (gxo#apps/catfish#39)
* Tue Oct 27 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.0
  * Added Ctrl+H shortcut to show/hide hidden files
    (gxo#apps/catfish#16)
  * Added "Today" and "Month" filters to the sidebar
    (gxo#apps/catfish#23)
  * Fulltext searches now include more text files
    (gxo#apps/catfish#7)
  * New app icon, now using an rDNS icon name (org.xfce.catfish)
  * Migrated ChangeLog to NEWS to better match Xfce projects
  * Renamed README to README.md and updated to match Xfce projects
  * Updated INSTALL to reference python3-specific packages
    (gxo#apps/catfish#36)
  * Various in-app icon updates (gxo#apps/catfish#15,
    gxo#apps/catfish#17, gxo#apps/catfish#26)
  * Added additional padding to Other and Custom gear icons
    (gxo#apps/catfish#20)
  * Check if zeitgeist daemon is running at startup
    (gxo#apps/catfish#34)
  * Correctly position custom filter popups above gear icon
    (gxo#apps/catfish#18)
  * Default to the current date in the custom date filters
    (gxo#apps/catfish#24)
  * Fix 'list' object has no attribute 'lower' (gxo#apps/catfish#9)
  * Fix fulltext freeze with special files (gxo#apps/catfish#32)
  * Fix python crash when some extension scheme is used
    (gxo#apps/catfish#35)
  * Fix statusbar moving on mouseover
  * Move custom file extension hint to tooltip (gxo#apps/catfish#25)
  * Sidebar entries no longer move when losing focus
    (gxo#apps/catfish#22)
  * Translation Updates
* Fri Feb 14 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed dependency conditional for Leap 15.2 build
* Wed Jan 15 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.13
  * Optimized svg and png assets
  * Fix missing results from symbolic links (bxo#16318)
  * Do not load catfishconfig during setup as it breaks Debian
    packaging
  * Translation Updates
* Thu Jan  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.12
  * Wayland and GNOME Shell support (bxo#16293)
  * All dialogs now use client-side decorations and are modal
  * Fixed typo "Catifish"
  * Temporary files are now excluded from releases
  * Releases now generate .bz2 files and display contents and checksums
  * Translation Updates
* Sat Dec 21 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.4.11
  - Radio indicators are now displayed on the layout options
  - Fix crashes when GdkDisplay or GdkScreen calls return None
    (lp#1822914)
  - Fix configuration of preferred window layout (bxo#16085)
  - Fix finding files in the target directory (bxo#15985, bxo#16233)
  - Fix symbolic link looping (bxo#16272)
  - Fix home (~) expansion for the start path
  - Fix asv-summary-has-dot-suffix
    (https://appstream.debian.org/sid/main/issues/catfish.html)
  - Translation Updates
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Fri Sep 13 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.10
  * New Features:
  - Preferences Dialog:
  * Window layout (titlebar vs. headerbar)
  * Display options (hidden files and sidebar)
  * Custom exclude directories
  - Option to close Catfish after opening a file (bxo#14888)
  * fix path exclusions (deb#926850)
  * Improved Application Menu:
  - Better use of space, padding, and margins
  - Clearer purpose labels
  - Keyboard accelerator for the sidebar (F9) is now displayed
  * General:
  - Better use of alt-accelerators
  - Improved installation instructions (bxo#15105)
  - Reduced warnings displayed in the terminal
  - Simplified Python 2/3 compatibility code
  - Standardized icon sizes, no more wrongly-sized icons in the results
  - Various code quality fixes (pylint, flake)
  * Search (Walk Method):
  - Enable traversing symbolic links, processing real paths only once
  - Add search priority, with each level processed alphabetically:
    1. XDG paths (Desktop, Documents, etc)
    2. Visible paths
    3. Hidden paths
  * Translation Updates
* Sat Sep  7 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Install appdata to metainfo (bxo#15752)
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Sun Aug 11 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.4.9
  * Fix path exclusions (deb#926850)
  * Translation updates
* Sat Jul 27 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.4.8
  * Thunar: Select file after opening file manager (bxo#14494)
  * Adjust locate parameters for the host OS (OpenBSD support)
  * Fix running on Wayland (bxo#15297)
  * Fix opening directories without XDG_CURRENT_DESKTOP (bxo#15099)
  * Fix exclusion of non-standard paths with the walk method
    (bxo#15206)
  * Add 'translator-credits' string to po files
    (bxo#15564)
  * Change "…" to "..." for consistency with other Xfce apps
    (bxo#15407)
  * Translation updates
* Thu Jan 31 2019 Maurizio Galli <maurizio.galli@gmail.com>
- dropped failing and obsolete --record-rpm build flag (boo#1123781)
* Sun Jan 27 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 1.4.7
  * General:
  - Cleaner, easier to read manpage contents
  - Added information about the --path flag to help and the manpage
  - Updated AppStream requirements to align with the latest spec
  - Replaced project URLs with HTTPS where possible
  * Desktop Integration:
  - The window layout now respects the current desktop (bxo#14486)
  - headerbar layout is used for Budgie, GNOME, and Pantheon
  - All other desktops use the traditional titlebar layout
  - This option can be overridden using the use-headerbar option in the
    Catfish configuration file (~/.config/catfish/catfish.rc)
  - Files can now be dragged into other applications (bxo#14492)
  - For file managers, the files will usually be copied to that
    location
  - For other applications, the files will be opened by the application
  * Performance:
  - Thumbnails will now only be generated when the thumbnail view is
    active (bxo#14689)
  - Added /dev to list of standard excluded directories
  - Files within /dev can still be searched if explicitly selected by
    the user
  * Bug Fixes:
  - Quoted search strings now allow for searching for specific phrases,
    instead of searching for actual quote characters (bxo#14501)
  - The file context menu can now be opened multiple times (bxo#14621)
  - Fix crash as startup with multi-file selection (lp#1753163)
  * Translation Updates
* Sat Jan 19 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 1.4.6
  * Upgraded thumbnailer, based on the FD.o Thumbnail Spec:
  - Improved error handling
  - Proper permissions for thumbnail directories and files
  - Logging of failed thumbnail generation
  - Saving of thumbnail file attributes
  - Support for relative thumbnail directories
  * The minimum GTK+ version has been bumped to 3.16.
  * Added inode/directory mimetype to desktop entry (bxo#14505)
  * Disabled overlay scrollbars to improve interacting with the results
    list (bxo#14487)
  * Enabled launching of executable AppImage files (bxo#14500)
  * Fixed invalid date in appdata (bxo#14502)
  * Replaced stock icons with standard Mime Type icons (bxo#14503)
  * Improved handling of exceptions when parsing settings (bxo#14491)
  * Improved handling of UnicodeDecodeErrors (bxo#14490)
  * Improved handling of PermissionErrors (bxo#14488)
  * Improved support for hidden files (bxo#14497)
  * Remember window size and position between sessions (bxo#14504)
  * Xfce: Open directories with the preferred file manager (bxo#14483)
  * Translation Updates
  - dropped outdated macros
  - added missing dep python3-gobject-Gdk required
* Fri Apr 27 2018 badshah400@gmail.com
- Drop Requires: gnome-icon-theme; all necessary icons are already
  provided by adwaita-icon-theme, a hard requirement for gtk3.
- Only run post(un) scripts on openSUSE < 1500; for later versions
  rpm file triggers take care of updating the icon cache already.
* Sat Apr 14 2018 avvissu@yandex.by
- Update to 1.4.5:
  * Translation Updates:
  - Catalan, Danish, Dutch, Lithuanian, Spanish, Swedish, Turkish
- Spec file cleanup
* Tue Jan 30 2018 avvissu@yandex.by
- Update to 1.4.4:
  * Installer cleanup
  * Updated appdata requirements
  * Add Keywords to desktop file (lintian), extend Categories
    with GTK (desktop-file-validate)
  * Catfish 1.4.3:
  * pycodestyle improvements
  * Improve search speed by discarding .cache and .gvfs when
    possible, add --basename to locate query
  * Stop all search methods when engine is stopped, improve error
    handling with thumbnails
- Update the sourceurl
- Use appdata instead of metainfo
- Fix: non-executable-script
* Tue Jun 13 2017 jengelh@inai.de
- Cure grammar problems in description.
* Sun Apr 10 2016 and.november@opensuse.org
- update to version 1.4.2
* Fri Oct  9 2015 and.november@opensuse.org
- update to version 1.3.3
* Sun Oct  5 2014 and.november@opensuse.org
- update to version 1.2.2
* Mon Mar 10 2014 and.november@opensuse.org
- update to version 1.0.2
* Sun Mar  2 2014 and.november@opensuse.org
- update to version 1.0.1
* Sat Feb  8 2014 and.november@opensuse.org
- update to version 1.0.0
